Struct diemdb::DiemDB [−][src]
pub struct DiemDB { /* fields omitted */ }Expand description
This holds a handle to the underlying DB responsible for physical storage and provides APIs for access to the core Diem data structures.
Implementations
pub fn open<P: AsRef<Path> + Clone>(
db_root_path: P,
readonly: bool,
prune_window: Option<u64>,
rocksdb_config: RocksdbConfig,
account_count_migration: bool
) -> Result<Self>
pub fn open_as_secondary<P: AsRef<Path> + Clone>(
db_root_path: P,
secondary_path: P,
rocksdb_config: RocksdbConfig
) -> Result<Self>
This opens db in non-readonly mode, without the pruner.
This force the db to update rocksdb properties immediately.
Gets an instance of BackupHandler for data backup purpose.